@@ -1,6 +1,7 @@
 from __future__ import with_statement
 
 import os
+from urllib import quote
 from urllib2 import HTTPError
 
 from django.conf import settings
@@ -120,9 +121,13 @@ class OAuthTwitterTest(TestCase):
 
     def test_association_anonymous(self):
         # Ensure we need a login.
-        response = self.client.get(reverse(oauthtwitter.associate))
-        self.assertEqual(response['Location'],
-                         'http://testserver%s' % settings.LOGIN_URL)
+        url = reverse('twitter_associate')
+        response = self.client.get(url)
+        self.assertEqual(
+            response['Location'],
+            'http://testserver%s?next=%s' % (self.old_login_url,
+                                             quote('http://testserver' + url))
+        )
 
     def test_association_user_add(self):
         # User adds association.
@@ -169,13 +174,13 @@ class OAuthTwitterTest(TestCase):
                           TwitterUser.objects.get, user=self.password)
         self.assertTrue(self.client.login(username=self.password.username,
                                           password=self.password.username))
-        response = self.client.post(reverse(oauthtwitter.associate),
+        response = self.client.post(reverse('twitter_associate'),
                                     {'action': 'remove',
                                      'twitter_id': '1'})
         self.assertEqual(response.status_code, 200)
         self.assertRaises(TwitterUser.DoesNotExist,
                           TwitterUser.objects.get, user=self.password)
-        response = self.client.post(reverse(oauthtwitter.associate))
+        response = self.client.post(reverse('twitter_associate'))
         self.assertEqual(response.status_code, 200)
         self.assertRaises(TwitterUser.DoesNotExist,
                           TwitterUser.objects.get, user=self.password)
@@ -223,10 +228,10 @@ class OAuthTwitterTest(TestCase):
             self.assertTrue(self.twitter.twitter)
             self.assertTrue(self.client.login(username=self.twitter.username,
                                               password=self.twitter.username))
-            response = self.client.post(reverse(oauthtwitter.associate))
+            response = self.client.post(reverse('twitter_associate'))
             self.assertEqual(response.status_code, 200)
             self.assertTrue(TwitterUser.objects.get(user=self.twitter))
-            response = self.client.post(reverse(oauthtwitter.associate),
+            response = self.client.post(reverse('twitter_associate'),
                                         {'action': 'remove',
                                          'twitter_id': '1'})
             self.assertEqual(response.status_code, 200)
@@ -247,7 +252,7 @@ class OAuthTwitterTest(TestCase):
             session = self.client.session
             session[REQUEST_KEY] = TOKEN.to_string()
             session.save()
-            response = self.client.get(reverse(oauthtwitter.associate))
+            response = self.client.get(reverse('twitter_associate'))
             self.assertEqual(response.status_code, 200)
 
     def test_callback(self):
